@@ -1,4 +1,4 @@
-# Copyrights 2007-2013 by [Mark Overmeer].
+# Copyrights 2007-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,12 +7,12 @@ use strict;
 
 package XML::Compile::SOAP::Daemon::NetServer;
 use vars '$VERSION';
-$VERSION = '3.06';
+$VERSION = '3.07';
 
 
 # The selected type of netserver gets added to the @ISA during new(),
 # so there are two base-classes!
-use base 'XML::Compile::SOAP::Daemon';
+use parent 'XML::Compile::SOAP::Daemon';
 our @ISA;
 
 use Log::Report 'xml-compile-soap-daemon';
@@ -113,10 +113,10 @@ sub post_bind_hook()
     lwp_socket_init $_ for @{$prop->{sock}};
 }
 
-sub setWsdlResponse($)
-{   my ($self, $fn) = @_;
+sub setWsdlResponse($;$)
+{   my ($self, $fn, $ft) = @_;
     trace "setting wsdl response to $fn";
-    lwp_wsdl_response $fn;
+    lwp_wsdl_response $fn, $ft;
 }
 
 # Overrule Net::Server's log() to translate it into Log::Report calls
